==> camel-karaf-4.7.0-source-release.zip: camel-karaf-4.7.0/tests/features/camel-avro/src/main/java/org/apache/karaf/camel/test/CamelAvroRouteSupplier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.karaf.camel.test;

import static org.apache.camel.builder.Builder.constant;

import java.io.IOException;
import java.util.function.Function;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.model.RouteDefinition;
import org.apache.camel.dataformat.avro.AvroDataFormat;
import org.apache.karaf.camel.itests.AbstractCamelSingleFeatureResultMockBasedRouteSupplier;
import org.osgi.service.component.annotations.Component;


@Component(
        name = "karaf-camel-avro-test",
        immediate = true,
        service = CamelAvroRouteSupplier.class
)
public class CamelAvroRouteSupplier extends AbstractCamelSingleFeatureResultMockBasedRouteSupplier {

    @Override
    protected Function<RouteBuilder, RouteDefinition> consumerRoute() {
        try (AvroDataFormat adf = new AvroDataFormat(Value.SCHEMA$)) {
            Value input = Value.newBuilder().setValue("OK").build();
            return builder -> builder.from("timer://testTimer?repeatCount=1")
                    .setBody(constant(input))
                    .marshal(adf)
                    .unmarshal(adf)
                    .log("received message ${body}");
        } catch (IOException e) {
            throw new IllegalStateException(e);
        }
    }

    @Override
    protected boolean producerEnabled() {
        return false;
    }
}

==> camel-karaf-4.10.7-source-release.zip: camel-karaf-4.10.7/tests/features/camel-avro/src/main/java/org/apache/karaf/camel/test/CamelAvroRouteSupplier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.karaf.camel.test;

import static org.apache.camel.builder.Builder.constant;

import java.io.IOException;
import java.util.function.Function;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.model.RouteDefinition;
import org.apache.camel.dataformat.avro.AvroDataFormat;
import org.apache.karaf.camel.itests.AbstractCamelSingleFeatureResultMockBasedRouteSupplier;
import org.apache.karaf.camel.itests.CamelRouteSupplier;
import org.osgi.service.component.annotations.Component;


@Component(
        name = "karaf-camel-avro-test",
        immediate = true,
        service = CamelRouteSupplier.class
)
public class CamelAvroRouteSupplier extends AbstractCamelSingleFeatureResultMockBasedRouteSupplier {

    @Override
    protected Function<RouteBuilder, RouteDefinition> consumerRoute() {
        try (AvroDataFormat adf = new AvroDataFormat(Value.SCHEMA$)) {
            Value input = Value.newBuilder().setValue("OK").build();
            return builder -> builder.from("timer://testTimer?repeatCount=1")
                    .setBody(constant(input))
                    .marshal(adf)
                    .unmarshal(adf)
                    .log("received message ${body}");
        } catch (IOException e) {
            throw new IllegalStateException(e);
        }
    }

    @Override
    protected boolean producerEnabled() {
        return false;
    }
}
